/*
 * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package java.dyn;

import java.io.Serializable;
import java.lang.reflect.Method;

public class CoroutineFrame implements Serializable {
	private static final long serialVersionUID = 5833458650915797757L;
	
	public Method method;
	public int bci;

	public int localCount;
	public int expressionCount;

	public long[] scalarValues;
	public Object[] objectValues;

	public CoroutineFrame(Method method, int bci, int localCount, int expressionCount, long[] scalarValues, Object[] objectValues) {
		this.method = method;
		this.bci = bci;
		this.localCount = localCount;
		this.expressionCount = expressionCount;
		this.scalarValues = scalarValues;
		this.objectValues = objectValues;
	}

	public int monitorCount() {
		return objectValues.length - localCount - expressionCount;
	}

	public void dump() {
		System.out.println("frame: " + method.getDeclaringClass().getSimpleName() +"."+method.getName() + "@" + bci + " (" + localCount + " locals, "+ expressionCount+" expressions, " + monitorCount() + " monitors)");
	}
}
